html = '''
<!DOCTYPE html><html lang="en">
<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1, minimum-scale=1, user-scalable=no">
<head>
</head>
<body style="margin: 0;">
    <div style="font-size: 34px; text-shadow: -.03em -.03em 0 black; content: ''; left: 0; top: 0; width: 100%; height: 100%; background: radial-gradient(circle, transparent 50%, transparent 50%), radial-gradient(circle, transparent 20%, white 50%) 30px 30px; background-size: .1em .1em;border-bottom-left-radius: 50px 20px;border-bottom-right-radius: 50px 20px;">
        <div style="opacity: 27.2%;">
            <table style="width: 100%;">
                <tr>
                    <td style="font-size: 25px; font-family: Phosphate; padding-top: 20px;text-align: right;padding-right: 39px;">!!!START_TIME!!!</td>
                </tr>
            </table>
            <table style="width: 100%;">
                <tr>
                    <td style="text-align: left; font-family: Phosphate; font-size: 35px; padding-top: 42px;padding-left: 43px;">STATUS .::</td>
                    <td style="text-align: right; font-family: Phosphate; font-size: 115px;padding-right: 25px;">!!!STATUS!!!</td>
                </tr>
            </table>
            <div style="border: 14px double #999;border-radius: 23px;margin: 13px;">
                    <table style="width: 100%; font-size: 21px;border-radius: 28px;padding-left: 14px;">
                        <tr>
                            <td style="padding: 5px; font-family: Trebuchet MS;">jobID</td>
                            <td style="width: 100%;padding-left: 44px; font-family: Trebuchet MS;">!!!JOB_ID!!!</td>
                        </tr>
                        <tr>
                            <td style="padding: 5px; font-family: Trebuchet MS;">descr.</td>
                            <td style="width: 100%;padding-left: 44px; font-family: Trebuchet MS;">!!!DESCR!!!</td>
                        </tr>
                        <tr>
                            <td style="padding: 5px; font-family: Trebuchet MS;">numTasks</td>
                            <td style="width: 100%;padding-left: 44px; font-family: Trebuchet MS;">!!!NUM_TASKS!!!</td>
                        </tr>
                        <tr>
                            <td style="padding: 5px; font-family: Trebuchet MS;">numActiveTasks</td>
                            <td style="width: 100%;padding-left: 44px; font-family: Trebuchet MS;">!!!NUM_ACTIVETASKS!!!</td>
                        </tr>
                        <tr>
                            <td style="padding: 5px; font-family: Trebuchet MS;">numCompletedTasks</td>
                            <td style="width: 100%;padding-left: 44px; font-family: Trebuchet MS;">!!!NUM_COMPLETEDTASKS!!!</td>
                        </tr>
                    </table>
            </div>
            <footer style="padding: 20px; text-align:center; font-size: 17px; font-family: Trebuchet MS;">
                <i>*This email was sent from an unmonitored mailbox, please do not reply.</i>
            </footer>
        </div>
    </div>
</body>
</html>


'''